boofun.analysis.fourier
=========================

.. automodule:: boofun.analysis.fourier


   .. rubric:: Functions

   .. autosummary::

      compute_and_fourier
      compute_mux3_fourier
      compute_nae3_fourier
      convolution
      dominant_coefficients
      even_part
      fourier_degree
      fourier_sparsity
      negate_inputs
      odd_part
      parseval_verify
      plancherel_inner_product
      restriction
      spectral_norm
      tensor_product
